package Bundle::Locale::CLDR::Southamerica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Southamerica

=head1 CONTENTS

Locale::CLDR::Locales::Es 0.46.0

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::Gn 0.46.0

Locale::CLDR::Locales::Nl 0.46.0

Locale::CLDR::Locales::Pt 0.46.0

Locale::CLDR::Locales::Qu 0.46.0

Locale::CLDR::Locales::Arn 0.46.0

Locale::CLDR::Locales::Kgp 0.46.0

Locale::CLDR::Locales::Yrl 0.46.0

Locale::CLDR::Locales::Es::Latn 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::Gn::Latn 0.46.0

Locale::CLDR::Locales::Nl::Latn 0.46.0

Locale::CLDR::Locales::Pt::Latn 0.46.0

Locale::CLDR::Locales::Qu::Latn 0.46.0

Locale::CLDR::Locales::Arn::Latn 0.46.0

Locale::CLDR::Locales::Kgp::Latn 0.46.0

Locale::CLDR::Locales::Yrl::Latn 0.46.0

Locale::CLDR::Locales::En::Latn::Fk 0.46.0

Locale::CLDR::Locales::En::Latn::Gy 0.46.0

Locale::CLDR::Locales::Es::Latn::Ar 0.46.0

Locale::CLDR::Locales::Es::Latn::Bo 0.46.0

Locale::CLDR::Locales::Es::Latn::Br 0.46.0

Locale::CLDR::Locales::Es::Latn::Cl 0.46.0

Locale::CLDR::Locales::Es::Latn::Co 0.46.0

Locale::CLDR::Locales::Es::Latn::Ec 0.46.0

Locale::CLDR::Locales::Es::Latn::Pe 0.46.0

Locale::CLDR::Locales::Es::Latn::Py 0.46.0

Locale::CLDR::Locales::Es::Latn::Uy 0.46.0

Locale::CLDR::Locales::Es::Latn::Ve 0.46.0

Locale::CLDR::Locales::Fr::Latn::Gf 0.46.0

Locale::CLDR::Locales::Gn::Latn::Py 0.46.0

Locale::CLDR::Locales::Nl::Latn::Sr 0.46.0

Locale::CLDR::Locales::Pt::Latn::Br 0.46.0

Locale::CLDR::Locales::Qu::Latn::Bo 0.46.0

Locale::CLDR::Locales::Qu::Latn::Ec 0.46.0

Locale::CLDR::Locales::Qu::Latn::Pe 0.46.0

Locale::CLDR::Locales::Arn::Latn::Cl 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Es::Latn::419 0.46.0

Locale::CLDR::Locales::Kgp::Latn::Br 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Br 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Co 0.46.0

Locale::CLDR::Locales::Yrl::Latn::Ve 0.46.0


=cut

1;

